==> material-react-table-0.3.5.tgz: package/src/utils/localization.ts <==
export interface MRT_Localization {
  actionsHeadColumnTitle: string;
  columnActionMenuButtonTitle: string;
  columnActionMenuItemClearSort: string;
  columnActionMenuItemGroupBy: string;
  columnActionMenuItemHideColumn: string;
  columnActionMenuItemSortAsc: string;
  columnActionMenuItemSortDesc: string;
  columnActionMenuItemUnGroupBy: string;
  columnShowHideMenuHideAll: string;
  columnShowHideMenuShowAll: string;
  expandAllButtonTitle: string;
  expandButtonTitle: string;
  filterTextFieldClearButtonTitle: string;
  filterTextFieldPlaceholder: string;
  rowActionButtonCancel: string;
  rowActionButtonSave: string;
  rowActionMenuButtonTitle: string;
  rowActionMenuItemEdit: string;
  rowActionsColumnTitle: string;
  searchTextFieldClearButtonTitle: string;
  searchTextFieldPlaceholder: string;
  selectAllCheckboxTitle: string;
  selectCheckboxTitle: string;
  showHideColumnsButtonTitle: string;
  toggleDensePaddingSwitchTitle: string;
  toggleFilterButtonTitle: string;
  toggleFullScreenButtonTitle: string;
  toggleSearchButtonTitle: string;
  toolbarAlertSelectionMessage: string;
  toolbarAlertGroupedByMessage: string;
  toolbarAlertGroupedThenByMessage: string;
}

export const defaultLocalization: MRT_Localization = {
  actionsHeadColumnTitle: 'Actions',
  columnActionMenuButtonTitle: 'Column Actions',
  columnActionMenuItemClearSort: 'Clear sorting',
  columnActionMenuItemGroupBy: 'Group by {column}',
  columnActionMenuItemHideColumn: 'Hide {column} column',
  columnActionMenuItemSortAsc: 'Sort by {column} ascending',
  columnActionMenuItemSortDesc: 'Sort by {column} descending',
  columnActionMenuItemUnGroupBy: 'Ungroup by {column}',
  columnShowHideMenuHideAll: 'Hide all',
  columnShowHideMenuShowAll: 'Show all',
  expandAllButtonTitle: 'Expand all',
  expandButtonTitle: 'Expand',
  filterTextFieldClearButtonTitle: 'Clear filter',
  filterTextFieldPlaceholder: 'Filter by {column}',
  rowActionButtonCancel: 'Cancel',
  rowActionButtonSave: 'Save',
  rowActionMenuButtonTitle: 'Row Actions',
  rowActionMenuItemEdit: 'Edit',
  rowActionsColumnTitle: 'Actions',
  searchTextFieldClearButtonTitle: 'Clear search',
  searchTextFieldPlaceholder: 'Search',
  selectAllCheckboxTitle: 'Select all',
  selectCheckboxTitle: 'Select row',
  showHideColumnsButtonTitle: 'Show/Hide columns',
  toggleDensePaddingSwitchTitle: 'Toggle dense padding',
  toggleFilterButtonTitle: 'Toggle filters',
  toggleFullScreenButtonTitle: 'Toggle full screen',
  toggleSearchButtonTitle: 'Toggle search',
  toolbarAlertSelectionMessage: '{selectedCount} of {rowCount} row(s) selected',
  toolbarAlertGroupedByMessage: 'Grouped by ',
  toolbarAlertGroupedThenByMessage: ', then by ',
};

==> material-react-table-0.4.5.tgz: package/src/utils/localization.ts <==
export interface MRT_Localization {
  actionsHeadColumnTitle: string;
  columnActionMenuButtonTitle: string;
  columnActionMenuItemClearSort: string;
  columnActionMenuItemGroupBy: string;
  columnActionMenuItemHideColumn: string;
  columnActionMenuItemSortAsc: string;
  columnActionMenuItemSortDesc: string;
  columnActionMenuItemUnGroupBy: string;
  columnShowHideMenuHideAll: string;
  columnShowHideMenuShowAll: string;
  expandAllButtonTitle: string;
  expandButtonTitle: string;
  filterTextFieldClearButtonTitle: string;
  filterTextFieldPlaceholder: string;
  rowActionButtonCancel: string;
  rowActionButtonSave: string;
  rowActionMenuButtonTitle: string;
  rowActionMenuItemEdit: string;
  rowActionsColumnTitle: string;
  searchTextFieldClearButtonTitle: string;
  searchTextFieldPlaceholder: string;
  selectAllCheckboxTitle: string;
  selectCheckboxTitle: string;
  showHideColumnsButtonTitle: string;
  toggleDensePaddingSwitchTitle: string;
  toggleFilterButtonTitle: string;
  toggleFullScreenButtonTitle: string;
  toggleSearchButtonTitle: string;
  toolbarAlertSelectionMessage: string;
  toolbarAlertGroupedByMessage: string;
  toolbarAlertGroupedThenByMessage: string;
}

export const defaultLocalization: MRT_Localization = {
  actionsHeadColumnTitle: 'Actions',
  columnActionMenuButtonTitle: 'Column Actions',
  columnActionMenuItemClearSort: 'Clear sort',
  columnActionMenuItemGroupBy: 'Group by {column}',
  columnActionMenuItemHideColumn: 'Hide {column} column',
  columnActionMenuItemSortAsc: 'Sort by {column} ascending',
  columnActionMenuItemSortDesc: 'Sort by {column} descending',
  columnActionMenuItemUnGroupBy: 'Ungroup by {column}',
  columnShowHideMenuHideAll: 'Hide all',
  columnShowHideMenuShowAll: 'Show all',
  expandAllButtonTitle: 'Expand all',
  expandButtonTitle: 'Expand',
  filterTextFieldClearButtonTitle: 'Clear filter',
  filterTextFieldPlaceholder: 'Filter by {column}',
  rowActionButtonCancel: 'Cancel',
  rowActionButtonSave: 'Save',
  rowActionMenuButtonTitle: 'Row Actions',
  rowActionMenuItemEdit: 'Edit',
  rowActionsColumnTitle: 'Actions',
  searchTextFieldClearButtonTitle: 'Clear search',
  searchTextFieldPlaceholder: 'Search',
  selectAllCheckboxTitle: 'Toggle select all',
  selectCheckboxTitle: 'Toggle select row',
  showHideColumnsButtonTitle: 'Show/Hide columns',
  toggleDensePaddingSwitchTitle: 'Toggle dense padding',
  toggleFilterButtonTitle: 'Toggle filters',
  toggleFullScreenButtonTitle: 'Toggle full screen',
  toggleSearchButtonTitle: 'Toggle search',
  toolbarAlertSelectionMessage: '{selectedCount} of {rowCount} row(s) selected',
  toolbarAlertGroupedByMessage: 'Grouped by ',
  toolbarAlertGroupedThenByMessage: ', then by ',
};
